==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/SchematicSyncPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import net.minecraft.class_2338;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_3492;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record SchematicSyncPacket(
    int slot, boolean deployed, class_2338 anchor, class_2470 rotation, class_2415 mirror
) implements class_2596<class_2792> {
    public static final class_9139<class_9129, SchematicSyncPacket> CODEC = class_9139.method_56906(
        class_9135.field_48550,
        SchematicSyncPacket::slot,
        class_9135.field_48547,
        SchematicSyncPacket::deployed,
        class_2338.field_48404,
        SchematicSyncPacket::anchor,
        class_2470.field_55987,
        SchematicSyncPacket::rotation,
        CatnipStreamCodecs.MIRROR,
        SchematicSyncPacket::mirror,
        SchematicSyncPacket::new
    );

    public SchematicSyncPacket(int slot, class_3492 settings, class_2338 anchor, boolean deployed) {
        this(slot, deployed, anchor, settings.method_15113(), settings.method_15114());
    }

    @Override
    public void apply(class_2792 listener) {
        AllHandle.onSchematicSync((class_3244) listener, this);
    }

    @Override
    public class_9145<SchematicSyncPacket> method_65080() {
        return AllPackets.SYNC_SCHEMATIC;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/SchematicSyncPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;

import java.util.function.BiConsumer;
import net.minecraft.class_2338;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_3244;
import net.minecraft.class_3492;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record SchematicSyncPacket(int slot, boolean deployed, class_2338 anchor, class_2470 rotation, class_2415 mirror) implements C2SPacket {
    public static final class_9139<class_9129, SchematicSyncPacket> CODEC = class_9139.method_56906(
        class_9135.field_48550,
        SchematicSyncPacket::slot,
        class_9135.field_48547,
        SchematicSyncPacket::deployed,
        class_2338.field_48404,
        SchematicSyncPacket::anchor,
        class_2470.field_55987,
        SchematicSyncPacket::rotation,
        CatnipStreamCodecs.MIRROR,
        SchematicSyncPacket::mirror,
        SchematicSyncPacket::new
    );

    public SchematicSyncPacket(int slot, class_3492 settings, class_2338 anchor, boolean deployed) {
        this(slot, deployed, anchor, settings.method_15113(), settings.method_15114());
    }

    @Override
    public class_9145<SchematicSyncPacket> method_65080() {
        return AllPackets.SYNC_SCHEMATIC;
    }

    @Override
    public BiConsumer<class_3244, SchematicSyncPacket> callback() {
        return AllHandle::onSchematicSync;
    }
}
